# Changelog

## [0.1.0] - 2023-03-31

### Added

- Automatic dependency locking
- Multi-environment support
- Environment activation
- Running commands defined in the `conda-project.yml` file and ad-hoc commands
- Defined environment variables with `.env` support for commands and environment activation
- Tested on Mac, Linux, and Windows
